# area4

Dividers in Python, the easy way! Many different types. [(As seen on PyPI!)](https://pypi.org/project/area4)  

[![MIT License Badge](https://img.shields.io/badge/license-MIT-green.svg)](https://github.com/area4lib/area4/blob/master/LICENSE)
[![PyPI Project Version](https://badge.fury.io/py/area4.svg)](https://pypi.org/project/area4)
[![Documentation Status](https://readthedocs.org/projects/area4/badge/?version=latest)](https://area4.readthedocs.io/en/latest/?badge=latest)
[![Project Status: Active](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
[![Build Status](https://api.cirrus-ci.com/github/area4lib/area4.svg)](https://cirrus-ci.com/github/area4lib/area4)  

area4 is a flexible Python divider library. It makes dividers in console output easy. Don't want to type out `---------` every time you need to use it? We've got you covered.  

## **Documentation** [can be found here](https://area4.readthedocs.io/en/stable/) <-------  

For help/troubleshooting see our [support information](https://github.com/area4lib/area4/blob/master/.github/SUPPORT.md).
